a glm object with the model under the null hypothesis (i.e. the covariates, the nuisance parameters).
model1
a glm or a matrix (or vector). If it is a glm object, it has the model under the alternative hypothesis. The variables in model1 are the same variables in model0 plus one or more variables to be tested. Alternatively, if
model1 is a matrix, it contains the tested variables column-wise.
score_type
The type of score that is computed. It is "orthogonalized", "effective" or "basic".
"effective" and "orthogonalized" take into account the nuisance estimation.
...
other arguments.
Author
Jesse Hemerik, Riccardo De Santis, Vittorio Giatti, Jelle Goeman and Livio Finos